@@ -17,6 +17,11 @@ def test_octocat():
     client = oc.OctocatClient()
     assert isinstance(client.api, OctocatAPIDescriptor)
     assert isinstance(client.api.test, OctocatAPIDescriptor)
+    mp = client.api.users
+    assert str(mp.klen) == 'GET users/klen'
+    assert str(mp.klen.get) == 'GET users/klen'
+    assert str(mp.klen.delete) == 'DELETE users/klen'
+    assert str(mp.lama.get) == 'GET users/lama'
 
 
 def test_anonimous():
@@ -30,9 +35,16 @@ def test_anonimous():
 
 
 def test_client():
-    client = oc.OctocatClient(loglevel='debug', **params)
+    client = oc.OctocatClient(**params)
     repo = client.api.repos.klen.pylama()
     assert repo['full_name']
 
 
+def test_mock():
+    client = oc.OctocatClient(**params)
+    with client.ctx(mock={'repos/klen/pylama': {'mocked': True}}):
+        repo = client.api.repos.klen.pylama()
+        assert repo == {'mocked': True}
+
+
 # pylama:ignore=W0611,D
